package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.Area;

/**
 * 地区信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface AreaMapper 
{
    /**
     * 查询地区信息
     * 
     * @param id 地区信息主键
     * @return 地区信息
     */
    public Area selectAreaById(Long id);

    /**
     * 查询地区信息列表
     * 
     * @param area 地区信息
     * @return 地区信息集合
     */
    public List<Area> selectAreaList(Area area);

    /**
     * 新增地区信息
     * 
     * @param area 地区信息
     * @return 结果
     */
    public int insertArea(Area area);

    /**
     * 修改地区信息
     * 
     * @param area 地区信息
     * @return 结果
     */
    public int updateArea(Area area);

    /**
     * 删除地区信息
     * 
     * @param id 地区信息主键
     * @return 结果
     */
    public int deleteAreaById(Long id);

    /**
     * 批量删除地区信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAreaByIds(Long[] ids);
}
